package stret;

import model.mec.SvetelnyMec;
import model.obor.Obor;
import model.obor.PlachyObor;
import model.obor.ZlyObor;
import model.rytier.Rytier;
import model.rytier.StatocnyRytier;

/**
 * Stret sluzi na simolovanie bojov medzi rytiermi a obrami rozneho druhu
 */
public class Stret {
	private Obor[] obor;
	private Rytier[] rytier;

	public Stret(int pocetRytierov, int pocetStatocnychRytierov, int pocetZlychObrov)
			throws NerovnyPocetBojovnikovException {

		inicializuj(pocetRytierov, pocetStatocnychRytierov, pocetZlychObrov);
	}

	private void inicializuj(int pocetRytierov, int pocetStatocnychRytierov, int pocetZlychObrov)
			throws NerovnyPocetBojovnikovException {

		boolean nerovnyPocetBojovnikov = (pocetZlychObrov <= pocetRytierov + pocetStatocnychRytierov);
		if (nerovnyPocetBojovnikov) {
			throw new NerovnyPocetBojovnikovException();
		}

		obor = new Obor[pocetZlychObrov];
		rytier = new Rytier[pocetRytierov + pocetStatocnychRytierov];

		// Mece ignorujeme
		for (int i = 0; i < pocetRytierov; ++i) {
			rytier[i] = new Rytier(100, new SvetelnyMec());
		}

		for (int i = pocetRytierov; i < pocetRytierov + pocetStatocnychRytierov; ++i) {
			rytier[i] = new StatocnyRytier(100, new SvetelnyMec());
		}

		for (int i = 0; i < pocetZlychObrov; ++i) {
			obor[i] = new ZlyObor(100);
		}

		for (int i = pocetZlychObrov; i < pocetRytierov + pocetStatocnychRytierov; ++i) {
			obor[i] = new PlachyObor(100);
		}
	}

	/**
	 * @return Spravu s informaciami o boji
	 */
	public String simulujStret() {
		StringBuilder sb = new StringBuilder("");

		for (int i = 0; i < rytier.length; ++i) {
			stret1na1(rytier[i], obor[i]);

			// Akumulujeme informacie o boji
			sb.append(i + 1)
					.append(": ")
					.append("rytier ").append(rytier[i].vratEnergiu())
					.append(" / ")
					.append("obor " + obor[i].vratEnergiu())
					.append("\n");
		}

		return sb.toString();
	}

	private void stret1na1(Rytier rytier, Obor obor) {
		rytier.utoc(obor);
	}

}